# wdig

[![wdig](https://github.com/jebu4/wdig/actions/workflows/wdig.yml/badge.svg)](https://github.com/jebu4/wdig/actions/workflows/wdig.yml)

where did it go?

## tasks

### dev ci

```bash
nox
```
